# Table of Contents

- [application-portfolio-assessment-define-scope](<./application-portfolio-assessment-define-scope.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Step 1: Add Data](<./Step-1-Add-Data.md>)
  - [Introduction to the Meta Model](<./Step-1-Add-Data/Introduction-to-the-Meta-Model.md>)
  - [Fact Sheet Types for Your Initial Assessment](<./Step-1-Add-Data/Fact-Sheet-Types-for-Your-Initial-Assessment.md>)
  - [Was this page helpful?](<./Step-1-Add-Data/Was-this-page-helpful.md>)
